@@ -1,11 +1,16 @@
 from .read_files import read_files
 from .bin_spectra import bin_spectra_uniform
+from .bin_spectra import bin_spectra_nonuniform
 from .qml_representation import qml_fchl_rep
 from .qml_utils import max_size
 from .linalg_solve import linalg_solve
 from .plot_spectrum import plot_stem
+from .plot_spectrum import plot_bar
+from .plot_spectrum import plot_bar_compare
 from .plot_spectrum import plot_smooth
 from .plot_spectrum import plot_stem_smooth
 from .predict import predict
 from .shuffle import shuffle
 from .prepare_trainingdata import prepare_trainingdata
+from .prepare_trainingdata import prepare_trainingdata_batch
+from .scores import confidence_score
