@@ -7,8 +7,8 @@ def predict(X,alpha,indices,iquery,max_size,sigmas,cut_distance):
     
     K=np.zeros(N_train)
     for itrain in range(N_train):
-        if np.mod(itrain,50) == 0:
-           print(itrain, 'kernel elements between query and training molecules calculated, ', N_train-itrain, 'remaining')
+   #    if np.mod(itrain,50) == 0:
+   #       print(itrain, 'kernel elements between query and training molecules calculated, ', N_train-itrain, 'remaining')
         Xt=X[indices[itrain]]
         Xq=X[indices[iquery]]
         Yt=np.zeros([1,max_size,5,max_size],dtype=float)
